#################################################################################
#################################################################################

### R code for computation of feature entropy

### VPR task: cry

### Barbora Hladka, Martin Holub

### ESSLLI 2015

### http://ufal.mff.cuni.cz/esslli2015

#################################################################################
#################################################################################
#################################################################################

entropy <- function(x){
  # computes H(x)
  # expects a factor
  
  p <- table(x) / NROW(x)
  return( -sum(p * log2(p)) )
} 

entropy.cond <- function(x, y){
  # computes H(x|y)
  # expects two factors of *the same length*
  
  N       <- NROW(x)	# should be equal to NROW(y)!
  p.y     <- table(y) / N			# p(y)
  p.joint <- as.vector(table(y, x)) / N		# p(y,x)
  p.cond  <- p.joint / rep(p.y, NROW(table(x)))	# p(x|y) = p(y,x) / p(y)
  H.cond  <- - sum( p.joint[p.joint > 0] * log2(p.cond[p.cond > 0]) ) # H(x|y)
  return( H.cond )
} 


###################################################################
###################################################################

### get data

examples <- read.csv("cry.development.csv", sep="\t")
n <- nrow(examples)

# remove id and target class tp
c <- examples[,-c(1,ncol(examples))]

# get the names of features
names <- names(c)

################

## compute entropy for each feature

# entropy of features
e <- apply(c, 2, entropy)
table(sort(round(e,2)))

# plot entropies
e <- sort(e)

pdf("e-cry.pdf",  width=8.5, height=5)
plot(e, main = "Entropy for 'cry'\n(entropy-cry.R)",
	xlab = "features",
	ylab ="H(A)",
	xaxt = 'n',
	pch = 19,
	type = "o",
	cex.main = 1.5,
        cex.axis = 1.5,
        cex.lab = 1.5)
dev.off()

# zoom
# H(A) > k
k = 0.5
e.k <- e[ e > k ] 

pdf("e-cry-threshold.pdf",  width=8.5, height=5)
plot(ce.k, main = "Entropy for 'cry'\n(entropy-cry.R)",
	xlab = "",
	ylab = "H(A) > 0.5",
	xaxt = 'n',
	pch = 19,
	type = "o",
	cex.main = 1.5,
        cex.axis = 1.5,
        cex.lab = 1.5)

axis(1, at=seq(1,length(ce.k), by=1),
	labels=names(ce.k),
	par(cex.axis=0.55),
	las = 2)
dev.off()

################

## compute conditional entropy for each feature and target value

# conditional entropy H(tp|A)
ce <- apply(c, 2, entropy.cond, y=examples$tp)
table(sort(round(ce,2)))

# plot conditional entropies
ce <- sort(ce)

pdf("ce-cry.pdf",  width=8.5, height=5)
plot(ce,  main = "Conditional entropy for 'cry'\n(entropy-cry.R)",
	xlab = "features",
	ylab = "H(P|A)",
	xaxt = 'n',
	pch = 19,
	type = "o",
	cex.main = 1.5,
        cex.axis = 1.5,
        cex.lab = 1.5)
dev.off()

# zoom
# H(P|A) > k
k = 0.5
ce.k <- ce[ ce > k ] 

pdf("ce-cry-threshold.pdf",  width=8.5, height=5)
plot(ce.k,  main = "Conditional entropy for 'cry'\n(entropy-cry.R)",
	xlab = "",
	ylab = "H(P|A) > 0.5",
	xaxt = 'n',
	pch = 19,
	type = "o",
	cex.main = 1.5,
        cex.axis = 1.5,
        cex.lab = 1.5)

axis(1, at=seq(1,length(ce.k), by=1),
	labels=names(ce.k),
	par(cex.axis=0.55), las = 2)
dev.off()

