#################################################################################
#################################################################################

### R code for computation of feature frequency

### VPR task: cry

### Barbora Hladka, Martin Holub

### ESSLLI 2015

### http://ufal.mff.cuni.cz/esslli2015

#################################################################################
#################################################################################
#################################################################################

fr <- function(x){
  # expects a vector of 1s and 0s
  # outputs number of 1s
  
  c <- sum(sapply(x, as.numeric))
  return( c )
} 

###################################################################
###################################################################

### get data

examples <- read.csv("cry.development.csv", sep="\t")
n <- nrow(examples)

# remove id and target class tp
c <- examples[,-c(1,ncol(examples))]

# get the names of features
names <- names(c)

################

## compute feature frequency for each feature
ff <- apply(c, 2, fr)
table(sort(ff))

# plot feature frequencies
f <- sort(ff)

pdf("../img/ff-cry.pdf",  width=8.5, height=5)
plot(f, main = "VPR task: cry\n(feature-frequency-cry.R)",
	xlab = "features", ylab="fr(A)",
	xaxt = 'n',  pch=19, type="o",
	cex.main=1.5,
        cex.axis=1.5,
        cex.lab=1.5)
dev.off()

# zoom
# ff(A) > k
k = 50
f.k <- f[ f > k ] 

pdf("../img/ff-cry-treshold.pdf",  width=8.5, height=5)
plot(f.k, main = "VPR task: cry\n(feature-frequency-cry.R)",
	xlab = "", ylab="fr(A) > 50",
	xaxt = 'n',  pch=19, type="o",
	cex.main=1.5,
        cex.axis=1.5,
        cex.lab=1.5)

axis(1, at=seq(1,length(f.k), by=1),
	labels=names(f.k), par(cex.axis=0.5), las = 2)
dev.off()

################

