#################################################################################
#################################################################################

### R code for analyzing the IMDb ratings

### MOV task

### Barbora Hladka, Martin Holub

### ESSLLI 2015

### http://ufal.mff.cuni.cz/esslli2015

#################################################################################
#################################################################################

## get examples, votes, movies, users
source("load-mov-data.R")

# function na.omit() returns the object with listwise deletion of missing values.
# create new dataset without missing data 
imdb <- na.omit(examples$imdb_rating)
mu <- mean(imdb)
sigma <- sd(imdb)

pdf("histogram-normal-curve-imdb-rating.pdf")
hist(imdb,
	main = "Histogram with normal curve \n (imdb_rating.R)", 
	xlab = "IMDb rating",
	ylab = "density",
	prob = TRUE, 
	cex.main = 2,
	cex.lab = 2)

abline(v = mu,
	col = "red",
	lwd = 3)

curve(dnorm(x, mean = mu, sd = sigma),
	from = 1,
	to = 10,
	add = T,
	lwd = 2,
	col = "blue",
	lty = 1)

axis(1,
	at = mu,
	labels = expression(bold(bar(imdb_rating))), 
	lwd = 4,
	cex.axis = 0.7,
	col = "red")

dev.off()


### graphically
pdf("qqplot-true.pdf", width=5, height=4)
# QQ plot for a sample of 99,981 normal (7.22, 1.00)-distributed random numbers
qqnorm(rnorm(length(imdb), mu, sigma))

# p=2.5%, xp=1.96
abline(v=qnorm(0.025, 0, 1),
	col = "grey")

abline(h=qnorm(0.025, mu, sigma),
	col = "grey")
dev.off()

# QQ plot for imdb
pdf("qqplot-imdb_rating.pdf", width=5, height=4)
qqnorm(imdb,
	main="IMDb Q-Q plot(imdb_rating.R)")
dev.off()
# it's clear that we are not dealing with a normal distribution

### test

# Kolgomorov-Smirnov ONE-SAMPLE test
ks.test(jitter(imdb), "pnorm", mu, sigma)



