#################################################################################
#################################################################################

### R code to draw mosaic plot for Star Wars' ratings 

### MOV task

### Barbora Hladka, Martin Holub

### ESSLLI 2015

### http://ufal.mff.cuni.cz/esslli2015

#################################################################################
#################################################################################

## get examples, votes, movies, users
source("load-mov-data.R")
library("vcd")

# Star Wars ratings
movie <- subset(examples, movie == 50)

# contingency table for gender and rating
ct <- table(movie$gender, movie$rating)
margin.table(ct)
addmargins(ct)
round(prop.table(ct),2)

# mosaic plot

names(dimnames(ct)) <- c("gender", "rating")

pdf("mosaic-plot.pdf")
mosaic(ct,
	main = "Mosaic plot (mosaic-plot.R)",
	pop = FALSE,
	highlighting = 1:2,
	labeling_args = list(rot_labels=c(bottom=0, top=0, left=0),
	gp_labels = gpar(fontsize=13),
	offset_labels = c(0,0,0,1.45)))

# add labels to plot
labeling_cells(text=ct,
	clip_cells = FALSE, 
	gp_text = gpar(fontsize=13))(ct)
dev.off()


