#################################################################################
#################################################################################

### R code for computing Pearson's Contingency Coefficient

### MOV task

### Barbora Hladka, Martin Holub

### ESSLLI 2015

### http://ufal.mff.cuni.cz/esslli2015

#################################################################################
#################################################################################

## Pearson's Contingency Coefficient (PCC)

pcc <- function(x){
	 # expects contingency table
	n <- sum(x)
	res <- chisq.test(x)
	cc <- sqrt(res$statistic/(res$statistic+n))
	tmp <- min(nrow(x), ncol(x))
	cc_max <- sqrt( (tmp - 1) /tmp )

	return( cc[[1]]/cc_max[[1]] )
} 

#############

## get examples, votes, movies, users
source("load-mov-data.R")

#############

# compute values of Pearson Contingency Coefficent for each pair of features

# work with some features only and target value
e <- examples[,-c(1:4,9:10,29:30)]

# number of features
f <- length(names(e))
fnames <- names(e)
fnames <- gsub("^.*?_","",fnames)

# matrix with PCCs 
m <- matrix(1, nrow=f, ncol=f)
for(i in 1:f){
	for(j in 1:f){
	ct <- table(e[,i], e[,j])
	m[i,j] <- pcc(ct)
	}
}

# display values of PCCs
for(i in 1:f){
barplot(m[i,-i],
	main = fnames[i],
	xlab = "",
	names.arg = fnames[-i],
	ylab = "Pearson contingency coefficient",
	cex.lab = 1.25,
	cex.names = 0.8,
	las = 2)
}

# display selection of values
pdf("pcc-age-gender-occupation-stars.pdf", width=8.5, height=5)
par(mfrow=c(2,2))

# age
i = 1
barplot(m[i,-i], main = fnames[i], xlab = "",
		names.arg = fnames[-i],
		ylab= "Pearson contingency coefficient",
		cex.lab=1.25, cex.names=0.8, las=2)

# gender
i = 2
barplot(m[i,-i], main = fnames[i], xlab = "",
		names.arg = fnames[-i],
		ylab= "",
		cex.lab=1.25, cex.names=0.8, las=2)

# occupation
i = 3
barplot(m[i,-i], main = fnames[i], xlab = "",
		names.arg = fnames[-i],
		ylab= "Pearson contingency coefficient",
		cex.lab=1.25, cex.names=0.8, las=2)

# stars
i = 25
barplot(m[i,-i], main = fnames[i], xlab = "",
		names.arg = fnames[-i],
		ylab= "",
		cex.lab=1.25, cex.names=0.8, las=2)

dev.off()

#############

# compute values of Pearson Contingency Coefficent for a (feature, target value) pair
v <- numeric(0)
for(i in 1:f){
	ct <- table(e[,i], examples$rating)
	v[i] <- pcc(ct)
	}
}

pdf("pcc-features-target.pdf", width=8.5, height=5)
barplot(v,
	main = "rating (pearson-contingency-coefficient-mov.R)",
	xlab = "",
	names.arg = fnames,
	ylab = "Pearson contingency coefficient",
	cex.lab = 1.25,
	cex.names = 0.8,
	las = 2)
dev.off()






