#################################################################################
#################################################################################

### R code for Pearson's Contingency Coefficient

### VPR task

### Barbora Hladka, Martin Holub

### ESSLLI 2015

### http://ufal.mff.cuni.cz/esslli2015

#################################################################################
#################################################################################

## Pearson's Contingency Coefficient (PCC)

pcc <- function(x){
	 # expects contingency table
	n <- sum(x)
	res <- chisq.test(x)
	cc <- sqrt(res$statistic/(res$statistic+n))
	tmp <- min(nrow(x), ncol(x))
	cc_max <- sqrt( (tmp - 1) /tmp )
	return( cc[[1]]/cc_max[[1]] )
} 

## get data

examples <- read.csv("cry.development.csv", sep="\t")
n <- nrow(examples)

############

## remove id and target class tp
c.0 <- examples[,-c(1,ncol(examples))]
## remove features with 0s only
c.1 <- c.0[,colSums(as.matrix(sapply(c.0, as.numeric)) )!=0]
## remove features with 1s only
c.2 <- c.1[,colSums(as.matrix(sapply(c.1, as.numeric)) )!=n]
## remove features with # 1s less or equal than m
m <- 0
c.3 <- c.2[,colSums(as.matrix(sapply(c.2, as.numeric)) ) > m]
## remove column duplicates 
c <- data.frame(t(unique(t(as.matrix(c.3)))))
# get the names of features
names <- names(c)
f <- length(names)

# compute values of PCCs for a (feature, target value) pair

v <- numeric(0)
for(i in 1:f){
	ct <- table(c[,i], examples$tp)
	v[i] <- pcc(ct)
	}

v.names <- data.frame(v,names)
v.names <- v.names[order(v.names$v),]

# zoom
# pcc > k
k = 0.3
v.names.k <- subset(v.names, v.names$v > k)

pdf("pcc-cry-threshold.pdf",  width=8.5, height=5)
plot(v.names.k$v, main = "Pearson contingency coefficient for 'cry'\n (pearson-contingency-coefficient-vpr.R)",
	xaxt = 'n',
	xlab = "",
	ylab = "pcc(A,P)>0.3",
	pch = 19,
	type = "o",
	cex.main = 1.5,
        cex.axis = 1.5,
        cex.lab = 1.5)

axis(1, at=seq(1,nrow(v.names.k), by=1),
	labels=v.names.k$names,
	par(cex.axis=0.55),
	las = 2)
dev.off()



